==> korweblog-1.5.8.tar.gz: korweblog-1.5.8/admin/config-extend.php <==
<?
/*--------------------------------------------------------------------
   KorWeblog :: Highly Customizable Weblog/CMS
   Copyright (C) 2001,2002 by Im Eunjea <eunjea@kldp.org>
   For detail of license and/or other info, see the file doc/COPYING.
   http://weblog.kldp.org
----------------------------------------------------------------------

LICENSE

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software 
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
----------------------------------------------------------------------*/

include("../include/common.inc.php");
include("auth.inc.php");

settype($act, "string");
if ($act == "bosinit") {
   SqlQuery("update T_Counter set Hit = 0");
} else if ($act == "timeinit") {
   SqlQuery("delete from T_Stats_date");
   SqlQuery("update T_Stats_hour set hits = 0");
   SqlQuery("update T_Stats_month set hits = 0");
   SqlQuery("update T_Stats_week set hits = 0");
}

$head = _EXTCONT;
include("../include/header.inc.php");

$VAR["Heading"] = _EXTCONT;

$out = new KWL_Html;
$VAR["Content"] = $out->form_start("admin/submit.php","config")
. $out->table_start("100%",'',1,0,3) ."
<TR>
   <TD>HTTP Referer</TD>
   <TD>". $out->radio("Referer",array(_NOTUSE,_USE),$CONF['Referer']) ."
   <BR>". _REFER_LIMIT .": "
   . $out->select("Referer_limit",array( 0 => _REFER_LIMIT_NO,
                                        500 => 500,
                                        1000 => 1000,
                                        2000 => 2000,
                                        3000 => 3000,
                                        4000 => 4000,
                                        5000 => 5000,
                                        10000 => 10000),
                   $CONF['Referer_limit']) ."
   <BR><small>". _ONLY_SESSION ."</small>
   </TD>
</TR>

<TR>
	<TD>". _LINKS ."</TD>
	<TD>". $out->select("Links",array(_NOTUSE,_LINK_ANYONE,_LINK_ONLYADMIN,_LINK_FREE),$CONF['Links']) ."</TD>
</TR>

<TR>
	<TD>". _STATS ."</TD>
	<TD>". $out->radio("SiteStats",array(_NOTUSE,_USE),$CONF['SiteStats']) ."</TD>
</TR>

<TR>
	<TD>". _COUNTER ."</TD>
	<TD>". $out->radio("Counter",array(_NOTUSE,_USE),$CONF['Counter']) ."
   <small>(<a href=\"config-extend.php?act=bosinit\">". _COUNT_INIT ."</a>)
   <BR>". _ONLY_SESSION ."</small>
   </TD>
</TR>

<TR>
	<TD>". _TIME_COUNTER ."</TD>
	<TD>". $out->radio("Time_Counter",array(_NOTUSE,_USE),$CONF['Time_Counter']) ."
   <small>(<a href=\"config-extend.php?act=timeinit\">". _COUNT_INIT ."</a>)
   <BR>". _ONLY_SESSION ."</small>
   </TD>
</TR>

<TR>
	<TD>". _ARCHIVE ."</TD>
	<TD>". $out->radio("Archive",array(_NOTUSE,_USE),$CONF['Archive']) ."</TD>
</TR>

<TR>
   <TD>". _DOWNLOAD ."</TD>
   <TD>". $out->radio("download",array(_NOTUSE,_USE),$CONF['download']) ."</TD>
</TR>

<TR>
   <TD>FAQ</TD>
   <TD>". $out->radio("FAQ",array(_NOTUSE,_USE),$CONF['FAQ']) ."</TD>
</TR>

<TR>
   <TD>Apache Style log</TD>
   <TD>". $out->radio("apache_log",array(_NOTUSE,_USE),$CONF['apache_log']) ."
	<BR>log file: $CONF[G_PATH]/logs/access_log</TD>
</TR>
<TR>
	<TD COLSPAN=2>"
   . $out->input_form("hidden","what","config-extend")
   . $out->input_form("submit",'',_SAVE_CHANGE) ."</TD>
</TR>". $out->table_end() . $out->form_end();

KWL_DrawMain($VAR);
include("../include/footer.inc.php");
?>

==> korweblog-1.5.9.tar.gz: korweblog-1.5.9/admin/config-extend.php <==
<?
/*--------------------------------------------------------------------
   KorWeblog :: Highly Customizable Weblog/CMS
   Copyright (C) 2001-2004 by Im Eunjea <eunjea@kldp.org>
   For detail of license and/or other info, see the file doc/COPYING.
   http://weblog.kldp.org
----------------------------------------------------------------------

LICENSE

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software 
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
----------------------------------------------------------------------*/

include("../include/common.inc.php");
include("auth.inc.php");

settype($act, "string");
if ($act == "bosinit") {
   SqlQuery("update T_Counter set Hit = 0");
} else if ($act == "timeinit") {
   SqlQuery("delete from T_Stats_date");
   SqlQuery("update T_Stats_hour set hits = 0");
   SqlQuery("update T_Stats_month set hits = 0");
   SqlQuery("update T_Stats_week set hits = 0");
}

$head = _EXTCONT;
include("../include/header.inc.php");

$VAR["Heading"] = _EXTCONT;

$out = new KWL_Html;
$VAR["Content"] = $out->form_start("admin/submit.php","config")
. $out->table_start("100%",'',1,0,3) ."
<TR>
   <TD>HTTP Referer</TD>
   <TD>". $out->radio("Referer",array(_NOTUSE,_USE),$CONF['Referer']) ."
   <BR>". _REFER_LIMIT .": "
   . $out->select("Referer_limit",array( 0 => _REFER_LIMIT_NO,
                                        500 => 500,
                                        1000 => 1000,
                                        2000 => 2000,
                                        3000 => 3000,
                                        4000 => 4000,
                                        5000 => 5000,
                                        10000 => 10000),
                   $CONF['Referer_limit']) ."
   <br />". _ONLY_SESSION ."
   </TD>
</TR>

<TR>
	<TD>". _LINKS ."</TD>
	<TD>". $out->select("Links",array(_NOTUSE,_LINK_ANYONE,_LINK_ONLYADMIN,_LINK_FREE),$CONF['Links']) ."</TD>
</TR>

<TR>
	<TD>". _STATS ."</TD>
	<TD>". $out->radio("SiteStats",array(_NOTUSE,_USE),$CONF['SiteStats']) ."</TD>
</TR>

<TR>
	<TD>". _COUNTER ."</TD>
	<TD>". $out->radio("Counter",array(_NOTUSE,_USE),$CONF['Counter']) ."
   (<a href=\"config-extend.php?act=bosinit\">". _COUNT_INIT ."</a>)
   <BR>". _ONLY_SESSION ."
   </TD>
</TR>

<TR>
	<TD>". _TIME_COUNTER ."</TD>
	<TD>". $out->radio("Time_Counter",array(_NOTUSE,_USE),$CONF['Time_Counter']) ."
   (<a href=\"config-extend.php?act=timeinit\">". _COUNT_INIT ."</a>)
   <BR>". _ONLY_SESSION ."
   </TD>
</TR>

<TR>
	<TD>". _ARCHIVE ."</TD>
	<TD>". $out->radio("Archive",array(_NOTUSE,_USE),$CONF['Archive']) ."</TD>
</TR>

<TR>
   <TD>". _DOWNLOAD ."</TD>
   <TD>". $out->radio("download",array(_NOTUSE,_USE),$CONF['download']) ."</TD>
</TR>

<TR>
   <TD>FAQ</TD>
   <TD>". $out->radio("FAQ",array(_NOTUSE,_USE),$CONF['FAQ']) ."</TD>
</TR>

<TR>
   <TD>Apache Style log</TD>
   <TD>". $out->radio("apache_log",array(_NOTUSE,_USE),$CONF['apache_log']) ."
	<BR>log file: $CONF[G_PATH]/logs/access_log</TD>
</TR>
<TR>
	<TD COLSPAN=2>"
   . $out->input_form("hidden","what","config-extend")
   . $out->input_form("submit",'',_SAVE_CHANGE) ."</TD>
</TR>". $out->table_end() . $out->form_end();

KWL_DrawMain($VAR);
include("../include/footer.inc.php");
?>
